@@ -15,22 +15,22 @@
 # You should have received a copy of the GNU General Public License
 # along with ciTools. If not, see <http://www.gnu.org/licenses/>.
 
-add_pi_lm_log <- function(tb, fit, alpha = 0.05, names = NULL, yhatName) {
+add_pi_lm_log <- function(df, fit, alpha = 0.05, names = NULL, yhatName) {
  
     if (is.null(names)) {
         names[1] <- paste("LPB", alpha/2, sep = "")
         names[2] <- paste("UPB", 1 - alpha/2, sep = "")
     }
-    if ((names[1] %in% colnames(tb))) {
+    if ((names[1] %in% colnames(df))) {
         warning ("These PIs may have already been appended to your dataframe. Overwriting.")
     }
  
-  out <- predict(fit, tb, interval = "prediction", level = 1 - alpha)
-    if(is.null(tb[[yhatName]]))
-        tb[[yhatName]] <- exp(out[, 1])
-  tb[[names[1]]] <- exp(out[, 2])
-  tb[[names[2]]] <- exp(out[, 3])
-  tibble::as_data_frame(tb)
+  out <- predict(fit, df, interval = "prediction", level = 1 - alpha)
+    if(is.null(df[[yhatName]]))
+        df[[yhatName]] <- exp(out[, 1])
+  df[[names[1]]] <- exp(out[, 2])
+  df[[names[2]]] <- exp(out[, 3])
+  data.frame(df)
   
 }
 
