@@ -20,27 +20,27 @@
 #' This is the method \code{add_probs} uses if the model is of class
 #' \code{lm}. Probabilities are calculated parametrically,
 #' using a pivotal quantity.
-#' 
 #'
-#' @param tb A tibble or data frame of new data.
+#'
+#' @param df A data frame of new data.
 #' @param fit An object of class \code{lm}. Predictions are made with
 #'     this object.
 #' @param q A real number. A quantile of the response distribution.
 #' @param name \code{NULL} or a string. If \code{NULL}, probabilities
 #'     automatically will be named by \code{add_probs}, otherwise, the
-#'     probabilities will be named \code{name} in the returned tibble.
+#'     probabilities will be named \code{name} in the returned data frame.
 #' @param yhatName A character vector of length one. Names of the
 #' @param comparison \code{"<"}, or \code{">"}. If \code{comparison =
 #'     "<"}, then \eqn{Pr(Y|x < q)} is calculated for each observation in
-#'     \code{tb}. Otherwise, \eqn{Pr(Y|x > q)} is calculated.
+#'     \code{df}. Otherwise, \eqn{Pr(Y|x > q)} is calculated.
 #' @param log_response A logical. Default is \code{FALSE}. Set to
 #'     \code{TRUE} if the model is log-linear: \eqn{\log(Y) = X \beta
 #'     + \epsilon}.
 #' @param ... Additional arguments.
-#' 
-#' @return A tibble, \code{tb}, with predicted values and
+#'
+#' @return A dataframe, \code{df}, with predicted values and
 #'     probabilities attached.
-#' 
+#'
 #' @seealso \code{\link{add_ci.lm}} for confidence intervals for
 #'     \code{lm} objects, \code{\link{add_pi.lm}} for prediction
 #'     intervals of \code{lm} objects, and
@@ -59,24 +59,24 @@
 #' # Calculate the probability that a new dist will be greater than
 #' # 30, given the model.
 #' add_probs(cars, fit, q = 30, comparison = ">")
-#' 
+#'
 #' @export
 
-add_probs.lm <- function(tb, fit, q, name = NULL, yhatName = "pred",
+add_probs.lm <- function(df, fit, q, name = NULL, yhatName = "pred",
                          comparison = "<", log_response = FALSE, ...){
 
     if (is.null(name) && comparison == "<")
         name <- paste("prob_less_than", q, sep="")
     if (is.null(name) && comparison == ">")
         name <- paste("prob_greater_than", q, sep="")
-    if ((name %in% colnames(tb))) {
+    if ((name %in% colnames(df))) {
         warning ("These probabilities may have already been appended to your dataframe. Overwriting.")
     }
 
     if (log_response)
         q <- log(q)
 
-    out <- predict(fit, tb, interval = "prediction", se.fit = TRUE)
+    out <- predict(fit, df, interval = "prediction", se.fit = TRUE)
     fitted <- out$fit[,1]
     residual_df <- out$df
     se_fitted <- out$se.fit
@@ -87,8 +87,8 @@ add_probs.lm <- function(tb, fit, q, name = NULL, yhatName = "pred",
         t_prob <- pt(q = t_quantile, df = residual_df)
     if (comparison == ">")
         t_prob <- 1 - pt(q = t_quantile, df = residual_df)
-    if (is.null(tb[[yhatName]]))
-        tb[[yhatName]] <- fitted
-    tb[[name]] <- t_prob
-    tibble::as_data_frame(tb)
+    if (is.null(df[[yhatName]]))
+        df[[yhatName]] <- fitted
+    df[[name]] <- t_prob
+    data.frame(df)
 }
